pub fn array_res_to_vector_res<const D: usize>(
a_res: DBSCANResult<D>,
) -> VectorDBSCANResultExpand description
Transforms a vector of clusters containing points represented as arrays into a vector of clusters where each point is represented as a vector.