[][src]Type Definition appr_dbscan::utils::CellIndex

type CellIndex<const D: usize> = [i64; D];

Array that stores the indexes of the intervals of the axes in the D dimensional space that are occupied by a certain cell