DBSCANResult

Type Alias DBSCANResult 

pub type DBSCANResult<const D: usize> = Vec<Cluster<D>>;
Collection of all the cluster found by the DBSCAN algorithm. Its first element will be the collection of noise points.

Aliased Type

pub struct DBSCANResult<const D: usize> { /* private fields */ }