pub fn determine_intersection<const D: usize>(
q: &Point<D>,
params: &DBSCANParams,
index_c: &CellIndex<D>,
side_size: f64,
) -> IntersectionTypeExpand description
Determines the type of intersection between a cell and an approximated ball. The cell is determined by its center and the side of its size. Returns:
- IntersectionType::FullyCovered if the cell is completely contained in a ball with center
qand radiusepsilon(1 + rho); - IntersectionType::Disjoint if the cell is completely outside of a ball with center
qand radiusepsilon; - IntersectionType::Intersecting otherwise;