[][src]Function appr_dbscan::utils::determine_intersection

pub fn determine_intersection<const D: usize>(
    q: &Point<D>,
    params: &DBSCANParams,
    index_c: &CellIndex<D>,
    side_size: f64
) -> IntersectionType

Determines the type of intersection between a cell and an approximated ball. The cell is determined by its center and the side of its size. Returns:

  • IntersectionType::FullyCovered if the cell is completely contained in a ball with center q and radius epsilon(1 + rho);
  • IntersectionType::Disjoint if the cell is completely outside of a ball with center q and radius epsilon;
  • IntersectionType::Intersecting otherwise;