pub fn vector_input_to_array_input<const D: usize>(
v_in: Vec<VectorPoint>,
) -> Vec<Point<D>> ⓘExpand description
Translates a vector of points represented as vectors in a vector of points represented ad fixed length arrays. Panics if the points do not all have the same length.